summaryrefslogtreecommitdiff
path: root/dns/reversename.py
diff options
context:
space:
mode:
authorBob Halley <halley@dnspython.org>2020-05-08 07:02:48 -0700
committerBob Halley <halley@dnspython.org>2020-05-08 07:02:48 -0700
commitc8484ecb460ef90a9db6d32eef09542d3e850c57 (patch)
treee27ee464c97472d21e393fa234a7db9af5946423 /dns/reversename.py
parent91adcbf570bf5e00373ae47ceee0cefe684d5b70 (diff)
downloaddnspython-c8484ecb460ef90a9db6d32eef09542d3e850c57.tar.gz
in doco, text->str, binary->bytes
Diffstat (limited to 'dns/reversename.py')
-rw-r--r--dns/reversename.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/dns/reversename.py b/dns/reversename.py
index fd382a5..e0beb03 100644
--- a/dns/reversename.py
+++ b/dns/reversename.py
@@ -32,7 +32,7 @@ def from_address(text, v4_origin=ipv4_reverse_domain,
"""Convert an IPv4 or IPv6 address in textual form into a Name object whose
value is the reverse-map domain name of the address.
*text*, a ``text``, is an IPv4 or IPv6 address in textual form
(e.g. '127.0.0.1', '::1')
*v4_origin*, a ``dns.name.Name`` to append to the labels corresponding to
@@ -79,7 +79,7 @@ def to_address(name, v4_origin=ipv4_reverse_domain,
Raises ``dns.exception.SyntaxError`` if the name does not have a
reverse-map form.
- Returns a ``text``.
+ Returns a ``str``.
"""
if name.is_subdomain(v4_origin):
@@ -32,7 +32,7 @@ def from_address(text, v4_origin=ipv4_reverse_domain,
"""Convert an IPv4 or IPv6 address in textual form into a Name object whose
value is the reverse-map domain name of the address.
- *text*, a ``text``, is an IPv4 or IPv6 address in textual form
+ *text*, a ``str``, is an IPv4 or IPv6 address in textual form
(e.g. '127.0.0.1', '::1')
*v4_origin*, a ``dns.name.Name`` to append to the labels corresponding to